Crate brdd_rust

Crate brdd_rust 

Structs

BrddError
Standardized error object for BRDD.
DefaultExecutionContext
The default implementation of the ExecutionContext.

Traits

ClientService
Protocol for external adapters (APIs, DBs) to perform side-effects.
EnrichService
Protocol for services that fetch additional data needed for the UseCase.
ExecutionContext
The central state object passed around and returned by UseCases.
UseCase
The orchestrator.
ValidateService
Protocol for services dedicated to pure business logic validation.
ValidationContext
A subset of the context that allows adding errors and checking validity.

Attribute Macros

brdd_rule
brdd_use_case