Structs
- Brdd
Error - Standardized error object for BRDD.
- Default
Execution Context - The default implementation of the ExecutionContext.
Traits
- Client
Service - Protocol for external adapters (APIs, DBs) to perform side-effects.
- Enrich
Service - Protocol for services that fetch additional data needed for the UseCase.
- Execution
Context - The central state object passed around and returned by UseCases.
- UseCase
- The orchestrator.
- Validate
Service - Protocol for services dedicated to pure business logic validation.
- Validation
Context - A subset of the context that allows adding errors and checking validity.